@@ -1,7 +1,7 @@
 
 print <<'EOF';
 # Setup the language environment
-if test ${HOME}/.xcyrillic; then . ${HOME}/.xcyrillic; fi
+if [ -f ${HOME}/.xcyrillic ]; then . ${HOME}/.xcyrillic; fi
 EOF
 
 
