@@ -1,7 +1,7 @@
 
 print <<'EOF';
 # Setup the Cyrillic
-if test ${HOME}/.xcyrillic; then . ${HOME}/.xcyrillic; fi
+if [ -f ${HOME}/.xcyrillic ]; then . ${HOME}/.xcyrillic; fi
 
 # Check if the user suplies startup commands by him/herself
 xsession=~/.xsession
