@@ -41,7 +41,7 @@ fi
 if [ -n "$WINDOWID" -a -x /usr/bin/X11/xprop ] ; then
   XPROP=`xprop -id $WINDOWID WM_CLASS`
   case $XPROP in
-  *kterm* | *krxvt* | *kwterm* | *katerm* ) LANG=ja_JP.eucJP ;;
+  *kterm* | *krxvt* | *kwterm* | *katerm* ) LANG=ja_JP.EUC-JP ;;
   *UXTerm* ) LANG=ja_JP.UTF-8 ;;
   *hanterm* ) LANG=ko_KR.eucKR ;;
   *caterm* | *crxvt-big5* ) LANG=zh_TW.Big5 ;;
@@ -62,7 +62,7 @@ else
         LANG=C
       fi ;;
     jfbterm) : ;;
-    *) LANG=ja_JP.eucJP ;;
+    *) LANG=ja_JP.EUC-JP ;;
   esac
 fi
 case $LANG in
@@ -91,7 +91,7 @@ function rxvt {
     /usr/bin/rxvt $*
   fi
 }
-alias jfbterm='LANG=ja_JP.eucJP /usr/bin/jfbterm'
+alias jfbterm='LANG=ja_JP.EUC-JP /usr/bin/jfbterm'
 alias xemacs='XMODIFIERS= xemacs'
 # perl ˤ󤹤˥󥰤ФͭˤƤ
 # PERL_BADLANG=0 ; export PERL_BADLANG
